@@ -25,7 +25,7 @@ read_functions = {
 }
 
 
-v8_0_0 = {
+v9_1_0 = {
     "commands": {
         "is_open": {
             "name": "fxIsOpen",
@@ -53,8 +53,13 @@ v8_0_0 = {
             ],
             "returnType": c.c_int,
         },
-        "start_streaming_with_safety": {
+        "start_streaming": {
             "name": "fxStartStreaming",
+            "argTypes": [c.c_uint, c.c_uint, c.c_bool],
+            "returnType": c.c_int,
+        },
+        "start_streaming_with_safety": {
+            "name": "fxStartStreamingWithSafety",
             "argTypes": [c.c_uint, c.c_uint, c.c_bool, c.c_uint16],
             "returnType": c.c_int,
         },
